==> cotram_0.4-4.zip: cotram/NEWS.Rd <==

\name{NEWS}
\title{NEWS file for the cotram package}

\section{Changes in Version 0.4-4 (2023-05-25)}{
  \itemize{
    \item{Remove \code{mcotram} temporarily (will come back once \pkg{tram} 1.0-0 is available.}
  }
}

\section{Changes in Version 0.4-3 (2022-11-02)}{
  \itemize{
    \item{Update reference output to \pkg{tram} 0.8-0.}
  }
}

\section{Changes in Version 0.4-2 (2022-10-31)}{
  \itemize{
    \item{Prepare for \pkg{tram} 0.8-0 release.}
  }
}


\section{Changes in Version 0.4-1 (2022-07-14)}{
  \itemize{
    \item{Fix additional check problems.}
  }
}

\section{Changes in Version 0.4-0 (2022-07-06)}{
  \itemize{
    \item{Use \code{Surv} to define the count likelihood.}
    \item{Allow more flexible choices for the support via \code{prob}.}
    \item{Update documentation / examples.}
    \item{Sandra Siegfried takes over maintainership from Torsten Hothorn.}
  }
}

\section{Changes in Version 0.3-2 (2022-01-27)}{
  \itemize{
    \item{Import \code{confband} generic from \pkg{mlt}.}
  }
}


\section{Changes in Version 0.3-1 (2021-09-21)}{
  \itemize{
    \item{Fix additional check problems.}
  }
}


\section{Changes in Version 0.3-0 (2021-09-20)}{
  \itemize{
    \item{New function \code{mcotram} implementing a multi-species count transformation model.}
    \item{New dataset \code{spiders}.}
    \item{Add more reference output.}
  }
}


\section{Changes in Version 0.2-1 (2021-02-23)}{
  \itemize{
    \item{Implement discrete hazard functions for count transformation models.}
    \item{Exit vignette friendly when downloaded DVC data fails.}
  }
}

\section{Changes in Version 0.2-0 (2020-03-30)}{
  \itemize{
    \item{Paper on count transformation models is now available in MEE; DOI added.}
    \item{Update vignette.}
  }
}


\section{Changes in Version 0.1-1 (2019-10-02)}{
  \itemize{
    \item{Update notation in package vignette.}
  }
}


\section{Changes in Version 0.1-0 (2019-08-19)}{
  \itemize{
    \item{Version 0.1-0 published on CRAN.}
  }
}

==> cotram_0.6-0.zip: cotram/NEWS.Rd <==

\name{NEWS}
\title{NEWS file for the cotram package}

\section{Changes in Version 0.6-0 (2025-11-19)}{
  \itemize{
    \item{Bring back \code{mcotram}.}
    \item{Update aqua birds demo.}
    \item{Address Fedora LaTeX issue.}
  }
}

\section{Changes in Version 0.5-3 (2025-10-08)}{
  \itemize{
    \item{Fix \code{predict} for linear predictors in location-scale models.}
  }
}

\section{Changes in Version 0.5-2 (2024-09-18)}{
  \itemize{
    \item{Remove \code{mcotram} temporarily.}
  }
}

\section{Changes in Version 0.5-1 (2024-07-19)}{
  \itemize{
    \item{Fix additional check problems with Mac.}
  }
}


\section{Changes in Version 0.5-0 (2024-07-16)}{
  \itemize{
    \item{Bring \code{mcotram} back with \pkg{tram} 1.0-0.}
    \item{Update email address.}
  }
}

\section{Changes in Version 0.4-4 (2023-05-25)}{
  \itemize{
    \item{Remove \code{mcotram} temporarily (will come back once \pkg{tram} 1.0-0 is available).}
  }
}

\section{Changes in Version 0.4-3 (2022-11-02)}{
  \itemize{
    \item{Update reference output to \pkg{tram} 0.8-0.}
  }
}

\section{Changes in Version 0.4-2 (2022-10-31)}{
  \itemize{
    \item{Prepare for \pkg{tram} 0.8-0 release.}
  }
}


\section{Changes in Version 0.4-1 (2022-07-14)}{
  \itemize{
    \item{Fix additional check problems.}
  }
}

\section{Changes in Version 0.4-0 (2022-07-06)}{
  \itemize{
    \item{Use \code{Surv} to define the count likelihood.}
    \item{Allow more flexible choices for the support via \code{prob}.}
    \item{Update documentation / examples.}
    \item{Sandra Siegfried takes over maintainership from Torsten Hothorn.}
  }
}

\section{Changes in Version 0.3-2 (2022-01-27)}{
  \itemize{
    \item{Import \code{confband} generic from \pkg{mlt}.}
  }
}


\section{Changes in Version 0.3-1 (2021-09-21)}{
  \itemize{
    \item{Fix additional check problems.}
  }
}


\section{Changes in Version 0.3-0 (2021-09-20)}{
  \itemize{
    \item{New function \code{mcotram} implementing a multi-species count transformation model.}
    \item{New dataset \code{spiders}.}
    \item{Add more reference output.}
  }
}


\section{Changes in Version 0.2-1 (2021-02-23)}{
  \itemize{
    \item{Implement discrete hazard functions for count transformation models.}
    \item{Exit vignette friendly when downloaded DVC data fails.}
  }
}

\section{Changes in Version 0.2-0 (2020-03-30)}{
  \itemize{
    \item{Paper on count transformation models is now available in MEE; DOI added.}
    \item{Update vignette.}
  }
}


\section{Changes in Version 0.1-1 (2019-10-02)}{
  \itemize{
    \item{Update notation in package vignette.}
  }
}


\section{Changes in Version 0.1-0 (2019-08-19)}{
  \itemize{
    \item{Version 0.1-0 published on CRAN.}
  }
}
